Index: src/backend/commands/tablecmds.c
===================================================================
RCS file: /projects/cvsroot/pgsql/src/backend/commands/tablecmds.c,v
retrieving revision 1.218
diff -c -r1.218 tablecmds.c
*** src/backend/commands/tablecmds.c	19 Mar 2007 23:38:29 -0000	1.218
--- src/backend/commands/tablecmds.c	27 Mar 2007 17:59:36 -0000
***************
*** 287,298 ****
  	Datum		reloptions;
  	ListCell   *listptr;
  	AttrNumber	attnum;
  
  	/*
! 	 * Truncate relname to appropriate length (probably a waste of time, as
! 	 * parser should have done this already).
  	 */
! 	StrNCpy(relname, stmt->relation->relname, NAMEDATALEN);
  
  	/*
  	 * Check consistency of arguments
--- 287,310 ----
  	Datum		reloptions;
  	ListCell   *listptr;
  	AttrNumber	attnum;
+ 	char	   *relarrayname;
  
  	/*
! 	 * Truncate relname to appropriate length (probably a waste of time, as *
! 	 * parser should have done this already).  Because tables and views now get
! 	 * an array type, this depends on the relkind.
  	 */
! 	if (
! 		namespaceId != 11 && /* pg_catalog's namespace */
! 		(relkind == 'r' || relkind == 'v')
! 	)
! 	{
! 		StrNCpy(relname, stmt->relation->relname, NAMEDATALEN-2);
! 	}
! 	else
! 	{
! 		StrNCpy(relname, stmt->relation->relname, NAMEDATALEN);
! 	}
  
  	/*
  	 * Check consistency of arguments
***************
*** 496,501 ****
--- 508,549 ----
  	 */
  	relation_close(rel, NoLock);
  
+ 	/*
+ 	 * Add the array type if appropriate.
+ 	 */
+ 	if (
+ 		namespaceId != 11 && /* pg_catalog's namespace */
+ 		(relkind == 'r' || relkind == 'v')
+ 	)
+ 	{
+ 		relarrayname = makeArrayTypeName(relname);
+ 		TypeCreate(relarrayname,		/* Array type name */
+ 				   namespaceId,			/* Same namespace as parent */
+ 				   relationId,			/* relation oid, N/A here */
+ 				   0,					/* relkind, also N/A here */
+ 				   -1,					/* Internal size, unlimited */
+ 				   'c',					/* It's a complex type */
+ 				   DEFAULT_TYPDELIM,	/* Use the default */
+ 				   F_ARRAY_IN,			/* Macro for array input procedure */
+ 				   F_ARRAY_OUT,			/* Macro for array output procedure */
+ 				   F_ARRAY_RECV,		/* Macro for array receive (binary input) procedure */
+ 				   F_ARRAY_SEND,		/* Macro for array send (binary output) procedure */
+ 				   -1,					/* No input typmod */
+ 				   -1,					/* No output typmod */
+ 				   InvalidOid,			/* Default ANALYZE procedure */
+ 				   relationId,			/* The OID just created */
+ 				   InvalidOid,			/* No base type--this isn't a DOMAIN */
+ 				   NULL,				/* No default type value */
+ 				   NULL,				/* Don't send binary */
+ 				   false,				/* Never passed by value */
+ 				   'd',					/* Type alignment.  Should this be something else? */
+ 				   'x',					/* Always TOASTable */
+ 				   -1,					/* No typMod for regular composite types.  When we have domains over these, we should revisit. */
+ 				   0,					/* Array diminsions of typbasetype */
+ 				   false);				/* Type NOT NULL */
+ 		pfree(relarrayname);	/* Seems like the right thing to do here. */
+ 	}
+ 
  	return relationId;
  }
  
